@@ -1,11 +1,11 @@
 // SPDX-License-Identifier: BSD-2-Clause
-/* Copyright (C) 2014 - 2020 Intel Corporation. */
+/* Copyright (C) 2014 - 2021 Intel Corporation. */
 
 #include <memkind.h>
 
-#include <stdlib.h>
-#include <stdio.h>
 #include <errno.h>
+#include <stdio.h>
+#include <stdlib.h>
 
 int main(int argc, char **argv)
 {
@@ -49,8 +49,8 @@ int main(int argc, char **argv)
         fprintf(stderr, "Unable to allocate hbw_preferred string\n");
         return errno ? -errno : 1;
     }
-    hbw_preferred_hugetlb_str = (char *)memkind_malloc(
-                                    MEMKIND_HBW_PREFERRED_HUGETLB, size);
+    hbw_preferred_hugetlb_str =
+        (char *)memkind_malloc(MEMKIND_HBW_PREFERRED_HUGETLB, size);
     if (hbw_preferred_hugetlb_str == NULL) {
         perror("memkind_malloc()");
         fprintf(stderr, "Unable to allocate hbw_preferred_hugetlb string\n");
@@ -59,28 +59,31 @@ int main(int argc, char **argv)
     hbw_interleave_str = (char *)memkind_malloc(MEMKIND_HBW_INTERLEAVE, size);
     if (hbw_interleave_str == NULL) {
         perror("memkind_malloc()");
-        fprintf(stderr,"Unable to allocate hbw_interleave string\n");
+        fprintf(stderr, "Unable to allocate hbw_interleave string\n");
         return errno ? -errno : 1;
     }
-    highest_capacity_str = (char *)memkind_malloc(MEMKIND_HIGHEST_CAPACITY, size);
+    highest_capacity_str =
+        (char *)memkind_malloc(MEMKIND_HIGHEST_CAPACITY, size);
     if (highest_capacity_str == NULL) {
         perror("memkind_malloc()");
-        fprintf(stderr,"Unable to allocate highest_capacity string\n");
+        fprintf(stderr, "Unable to allocate highest_capacity string\n");
         return errno ? -errno : 1;
     }
 
     sprintf(default_str, "Hello world from standard memory\n");
     sprintf(hugetlb_str, "Hello world from standard memory with 2 MB pages\n");
     sprintf(hbw_str, "Hello world from high bandwidth memory\n");
-    sprintf(hbw_hugetlb_str, "Hello world from high bandwidth 2 MB paged memory\n");
-    sprintf(hbw_preferred_str,
-            "Hello world from high bandwidth memory if sufficient resources exist\n");
-    sprintf(hbw_preferred_hugetlb_str,
-            "Hello world from high bandwidth 2 MB paged memory if sufficient resources exist\n");
+    sprintf(hbw_hugetlb_str,
+            "Hello world from high bandwidth 2 MB paged memory\n");
+    sprintf(
+        hbw_preferred_str,
+        "Hello world from high bandwidth memory if sufficient resources exist\n");
+    sprintf(
+        hbw_preferred_hugetlb_str,
+        "Hello world from high bandwidth 2 MB paged memory if sufficient resources exist\n");
     sprintf(hbw_interleave_str,
             "Hello world from high bandwidth interleaved memory\n");
-    sprintf(highest_capacity_str,
-            "Hello world from highest capacity memory\n");
+    sprintf(highest_capacity_str, "Hello world from highest capacity memory\n");
 
     fprintf(stdout, "%s", default_str);
     fprintf(stdout, "%s", hugetlb_str);
