@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-2-Clause
-/* Copyright (C) 2014 - 2020 Intel Corporation. */
+/* Copyright (C) 2014 - 2021 Intel Corporation. */
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 
@@ -19,12 +19,14 @@ public:
 
     void *operator new(std::size_t size)
     {
-        return deriving_class::operator new(size, deriving_class::getClassKind());
+        return deriving_class::operator new(size,
+                                            deriving_class::getClassKind());
     }
 
     void *operator new[](std::size_t size)
     {
-        return deriving_class::operator new(size, deriving_class::getClassKind());
+        return deriving_class::operator new(size,
+                                            deriving_class::getClassKind());
     }
 
     void *operator new(std::size_t size, memkind_t memory_kind)
@@ -32,17 +34,17 @@ public:
         void *result_ptr = NULL;
         int allocation_result = 0;
 
-        //This check if deriving_class has specified alignment, which is suitable
-        //to be used with posix_memalign()
-        if(alignof(deriving_class) <  sizeof(void *)) {
+        // This check if deriving_class has specified alignment, which is
+        // suitable to be used with posix_memalign()
+        if (alignof(deriving_class) < sizeof(void *)) {
             result_ptr = memkind_malloc(memory_kind, size);
             allocation_result = result_ptr ? 1 : 0;
         } else {
-            allocation_result = memkind_posix_memalign(memory_kind, &result_ptr,
-                                                       alignof(deriving_class), size);
+            allocation_result = memkind_posix_memalign(
+                memory_kind, &result_ptr, alignof(deriving_class), size);
         }
 
-        if(allocation_result) {
+        if (allocation_result) {
             throw std::bad_alloc();
         }
 
@@ -61,7 +63,7 @@ public:
 
     void operator delete(void *ptr)
     {
-        memkind_free(0, ptr);
+        memkind_free(NULL, ptr);
     }
 
     void operator delete[](void *ptr)
@@ -76,11 +78,8 @@ public:
 
 protected:
     memkind_allocated()
-    {
-    }
+    {}
 
     ~memkind_allocated()
-    {
-    }
-
+    {}
 };
