@@ -28,11 +28,10 @@
 /* from jemalloc internals */
 struct arena_config_s {
     /* extent hooks to be used for the arena */
-    struct extent_hooks_s *extent_hooks;
+    extent_hooks_t *extent_hooks;
 
     /*
-     * Use provided hooks for metadata (base) allocations when true.
-     * Ignored if extent_hooks is NULL.
+     * Use extent hooks for metadata (base) allocations when true.
      */
     bool metadata_use_hooks;
 };
