@@ -1,37 +1,15 @@
-/*
-* Copyright (C) 2017 - 2018 Intel Corporation.
-* All rights reserved.
-*
-* Redistribution and use in source and binary forms, with or without
-* modification, are permitted provided that the following conditions are met:
-* 1. Redistributions of source code must retain the above copyright notice(s),
-*    this list of conditions and the following disclaimer.
-* 2. Redistributions in binary form must reproduce the above copyright notice(s),
-*    this list of conditions and the following disclaimer in the documentation
-*    and/or other materials provided with the distribution.
-*
-* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER(S) ``AS IS'' AND ANY EXPRESS
-* OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
-* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
-* EVENT SHALL THE COPYRIGHT HOLDER(S) BE LIABLE FOR ANY DIRECT, INDIRECT,
-* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-* PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
-* OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-* ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-*/
+// SPDX-License-Identifier: BSD-2-Clause
+/* Copyright (C) 2017 - 2021 Intel Corporation. */
 #pragma once
 
-#include <stdio.h>
 #include <assert.h>
-#include <map>
 #include <iterator>
+#include <map>
+#include <stdio.h>
 
 class Allocator
 {
 public:
-
     virtual void *malloc(size_t size) = 0;
     virtual void *calloc(size_t num, size_t size) = 0;
     virtual void *realloc(void *ptr, size_t size) = 0;
@@ -44,18 +22,16 @@ public:
     virtual bool is_high_bandwidth() = 0;
     virtual size_t get_page_size() = 0;
 
-    virtual ~Allocator(void) {}
+    virtual ~Allocator(void)
+    {}
 };
 
-class MemkindAllocator : public Allocator
+class MemkindAllocator: public Allocator
 {
 public:
-
     MemkindAllocator(memkind_memtype_t memtype, memkind_policy_t policy,
-                     memkind_bits_t flags) :
-        memtype(memtype),
-        policy(policy),
-        flags(flags)
+                     memkind_bits_t flags)
+        : memtype(memtype), flags(flags)
     {
         int ret = memkind_create_kind(memtype, policy, flags, &kind);
         assert(ret == MEMKIND_SUCCESS);
@@ -105,11 +81,10 @@ public:
             std::make_pair(MEMKIND_DEFAULT, MPOL_DEFAULT),
             std::make_pair(MEMKIND_HUGETLB, MPOL_DEFAULT),
             std::make_pair(MEMKIND_HBW_ALL_HUGETLB, MPOL_BIND),
-            std::make_pair(MEMKIND_HBW_ALL, MPOL_BIND)
-        };
+            std::make_pair(MEMKIND_HBW_ALL, MPOL_BIND)};
         auto it = kind_policy.find(kind);
 
-        if(it != std::end(kind_policy)) {
+        if (it != std::end(kind_policy)) {
             return it->second;
         }
         return -1;
@@ -117,22 +92,19 @@ public:
 
     virtual bool is_high_bandwidth()
     {
-        return  memtype == MEMKIND_MEMTYPE_HIGH_BANDWIDTH ||
-                kind == MEMKIND_HBW ||
-                kind == MEMKIND_HBW_HUGETLB ||
-                kind == MEMKIND_HBW_PREFERRED ||
-                kind == MEMKIND_HBW_INTERLEAVE;
+        return memtype == MEMKIND_MEMTYPE_HIGH_BANDWIDTH ||
+            kind == MEMKIND_HBW || kind == MEMKIND_HBW_HUGETLB ||
+            kind == MEMKIND_HBW_PREFERRED || kind == MEMKIND_HBW_INTERLEAVE;
     }
 
     virtual size_t get_page_size()
     {
-        if (kind == MEMKIND_HUGETLB ||
-            kind == MEMKIND_HBW_HUGETLB ||
+        if (kind == MEMKIND_HUGETLB || kind == MEMKIND_HBW_HUGETLB ||
             kind == MEMKIND_HBW_PREFERRED_HUGETLB ||
             (flags & MEMKIND_MASK_PAGE_SIZE_2MB)) {
-            return 2*MB;
+            return 2 * MB;
         }
-        return 4*KB;
+        return 4 * KB;
     }
 
     virtual ~MemkindAllocator()
@@ -145,14 +117,12 @@ public:
 private:
     memkind_t kind = NULL;
     memkind_memtype_t memtype = memkind_memtype_t();
-    memkind_policy_t policy = MEMKIND_POLICY_MAX_VALUE;
     memkind_bits_t flags = memkind_bits_t();
 };
 
-class HbwmallocAllocator : public Allocator
+class HbwmallocAllocator: public Allocator
 {
 public:
-
     HbwmallocAllocator(hbw_policy_t hbw_policy)
     {
         hbw_set_policy(hbw_policy);
@@ -207,18 +177,17 @@ public:
 
     virtual bool is_high_bandwidth()
     {
-        return  hbw_check_available() == 0;
+        return hbw_check_available() == 0;
     }
 
     virtual size_t get_page_size()
     {
         if (page_size == HBW_PAGESIZE_2MB) {
-            return 2*MB;
+            return 2 * MB;
         }
-        return 4*KB;
+        return 4 * KB;
     }
 
 private:
     hbw_pagesize_t page_size = HBW_PAGESIZE_4KB;
 };
-
