@@ -1,25 +1,25 @@
 // SPDX-License-Identifier: BSD-2-Clause
-/* Copyright (C) 2016 - 2020 Intel Corporation. */
+/* Copyright (C) 2016 - 2021 Intel Corporation. */
 
-#include <vector>
 #include "Task.hpp"
+#include <vector>
 
 class HugePageUnmap: public Task
 {
 
 public:
     HugePageUnmap(int operations, bool touch_memory, size_t alignment_size,
-                  size_t alloc_size, hbw_pagesize_t page_size) :
-        mem_operations_num(operations),
-        touch_memory(touch_memory),
-        alignment_size(alignment_size),
-        alloc_size(alloc_size),
-        page_size(page_size)
+                  size_t alloc_size, hbw_pagesize_t page_size)
+        : mem_operations_num(operations),
+          touch_memory(touch_memory),
+          alignment_size(alignment_size),
+          alloc_size(alloc_size),
+          page_size(page_size)
     {}
 
     ~HugePageUnmap()
     {
-        for(int i=0; i<mem_operations_num; i++) {
+        for (int i = 0; i < mem_operations_num; i++) {
             hbw_free(results[i].ptr);
         }
     };
@@ -28,13 +28,14 @@ public:
     {
         void *ptr = NULL;
 
-        for(int i=0; i<mem_operations_num; i++) {
-            int ret = hbw_posix_memalign_psize(&ptr, alignment_size, alloc_size, page_size);
+        for (int i = 0; i < mem_operations_num; i++) {
+            int ret = hbw_posix_memalign_psize(&ptr, alignment_size, alloc_size,
+                                               page_size);
 
             ASSERT_EQ(ret, 0);
             ASSERT_FALSE(ptr == NULL);
 
-            if(touch_memory) {
+            if (touch_memory) {
                 memset(ptr, alignment_size, alignment_size);
             }
 
@@ -58,4 +59,3 @@ private:
     size_t alloc_size;
     hbw_pagesize_t page_size;
 };
-
