@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-2-Clause
-/* Copyright (C) 2015 - 2020 Intel Corporation. */
+/* Copyright (C) 2015 - 2021 Intel Corporation. */
 #pragma once
 
 #include "Allocator.hpp"
@@ -8,9 +8,9 @@ class Workload
 {
 public:
     virtual bool run() = 0;
-    virtual ~Workload(void) {}
+    virtual ~Workload(void)
+    {}
 
 protected:
     Allocator *allocator;
 };
-
