@@ -2,5 +2,3 @@
 /usr/share/mpss/test/memkind-dt/decorator_test -a
 /usr/share/mpss/test/memkind-dt/gb_page_tests_bind_policy -a --gtest_filter=-*.*ext*
 /usr/share/mpss/test/memkind-dt/gb_page_tests_bind_policy -a --gtest_filter=-*.*ext*
-/usr/share/mpss/test/memkind-dt/bat_bind_tests -a
-/usr/share/mpss/test/memkind-dt/bat_interleave_tests -a
