@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: BSD-2-Clause
-/* Copyright (C) 2021 Intel Corporation. */
+/* Copyright (C) 2021-2022 Intel Corporation. */
 
-#include <memkind/internal/memkind_memtier.h>
+#include <memkind_memtier.h>
 
 #include <random>
 #include <thread>
